@@ -1,4 +1,4 @@
 import logging
 
-FMT = '%(asctime)-15s %(module)s %(levelname)s %(message)s'
+FMT = "%(asctime)-15s %(module)s %(levelname)s %(message)s"
 logging.basicConfig(format=FMT, level=logging.WARNING)
