@@ -1,6 +1,6 @@
 ##
 # This file is part of TALER
-# (C) 2014, 2015, 2016 Taler Systems SA
+# (C) 2014, 2015, 2016, 2020 Taler Systems SA
 #
 #  TALER is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
@@ -25,6 +25,8 @@ from django.core.exceptions import ValidationError
 from django import forms
 from django.core.validators import RegexValidator
 from urllib.parse import urlparse
+from taler.util.taler_error_codes import ErrorCode
+from http import HTTPStatus
 
 ##
 # Constant value for the biggest number the bank handles.
@@ -58,8 +60,8 @@ class InvalidSession(ValueError):
 class InternalServerError(Exception):
     def __init__(self, hint):
         self.hint = hint
-        self.http_status_code = 500
-        self.taler_error_code = 1011  # TALER_EC_INTERNAL_LOGIC_ERROR
+        self.http_status_code = HTTPStatus.INTERNAL_SERVER_ERROR
+        self.taler_error_code = ErrorCode.INTERNAL_LOGIC_ERROR
 
 
 ##
@@ -82,7 +84,7 @@ class JSONFieldException(ValueError):
         super(JSONFieldException, self).__init__(line)
         self.hint = line
         self.http_status_code = http_status_code
-        self.taler_error_code = 5106
+        self.taler_error_code = TalerErrorCode.BANK_JSON_INVALID
 
 
 ##
@@ -99,7 +101,7 @@ class URLParamValidationError(ValueError):
     def __init__(self, error, http_status_code):
         self.hint = json.stringify(error.as_json())
         self.http_status_code = http_status_code
-        self.taler_error_code = 5105
+        self.taler_error_code = ErrorCode.BANK_PARAMETER_MISSING_OR_INVALID
         super().__init__()
 
 
@@ -134,7 +136,9 @@ class BankValidator:
     def __init__(self, validator, data):
         self.validation_result = validator(data)
         if not self.validation_result.is_valid():
-            raise JSONFieldException(self.validation_result.errors, 400)
+            raise JSONFieldException(
+                self.validation_result.errors, HTTPStatus.BAD_REQUEST
+            )
 
     def get(self, name, default=None):
         ret = self.validation_result.cleaned_data.get(name)
