@@ -99,7 +99,6 @@ urlpatterns = [
     path("favicon.ico", views.ignore),
     path("config", views.config_view, name="config"),
     path("history", views.serve_history, name="history"),
-    path("public-accounts", views.serve_public_accounts, name="public-accounts"),
     path("payto-transfer", views.payto_transfer, name="payto-transfer"),
 ]
 
@@ -118,6 +117,7 @@ urlpatterns += i18n_patterns(
     path("register", views.register, name="register"),
     path("profile", views.profile_page, name="profile"),
     path("payto-form", views.payto_form, name="payto-form"),
+    path("wiretransfer-form", views.wiretransfer_form, name="wiretransfer-form"),
     path(
         "login",
         auth_views.LoginView.as_view(
@@ -126,6 +126,11 @@ urlpatterns += i18n_patterns(
         ),
         name="login",
     ),
+    path(
+        "public-accounts",
+        views.serve_public_accounts,
+        name="public-accounts",
+    ),
     path(
         "public-accounts/<str:name>",
         views.serve_public_accounts,
