@@ -49,6 +49,7 @@ from django.core.exceptions import ObjectDoesNotExist
 from datetime import datetime
 from .models import BankAccount, BankTransaction, TalerWithdrawOperation
 from taler.util.amount import Amount, SignedAmount
+from taler.util.payto import PaytoParse
 from taler.util.taler_error_codes import ErrorCode
 from http import HTTPStatus
 
@@ -99,21 +100,6 @@ def allow_origin_star(view_func):
 
     return wraps(view_func)(_decorator)
 
-
-class PaytoParse:
-    def __init__(self, payto_uri):
-        parsed_payto = urlparse(payto_uri)
-        if parsed_payto.scheme != "payto":
-            raise Exception("Bad Payto URI: '%s'" % payto_uri)
-        path_as_list = parsed_payto.path.split("/")
-        if len(path_as_list) == 0:
-            raise Exception("No account/user name found: '%s'" % payto_uri)
-        self.account = path_as_list[-1]
-        params = dict(parse_qsl(parsed_payto.query))
-        self.subject = params.get("subject")
-        self.amount = Amount.parse(params.get("amount"))
-
-
 ##
 # Exception raised upon failing login.
 #
@@ -308,10 +294,55 @@ class PaytoTransferForm(forms.Form):
     address = forms.CharField()
 
 
+@login_required
+def wiretransfer_form(request):
+    if request.method == "GET":
+        is_success, hint = get_session_hint(request)
+        context = dict(
+            currency=request.user.bankaccount.balance.amount.currency,
+            is_success=is_success,
+            hint=hint,
+        )
+        return render(request, "wiretransfer.html", context)
+
+    # A payment was submitted. 
+    try:
+        amount = Amount.parse(
+            "{}:{}".format(request.POST.get("currency"), request.POST.get("amount")
+        ))
+    except Exception:
+        set_session_hint(request, success=False, hint="Wrong amount specified.")
+        return redirect("wiretransfer-form")
+    try:
+        receiver_user = User.objects.get(username=request.POST.get("receiver"))
+    except User.DoesNotExist:
+        set_session_hint(request, success=False, hint="Money receiver was not found")
+        return redirect("wiretransfer-form")
+
+    try:
+        wire_transfer(
+            amount,
+            request.user.bankaccount,
+            receiver_user.bankaccount,
+            request.POST.get("subject", "not given")
+        )
+    except Exception as exception:
+        hint = str(exception)
+        if hasattr(exception, "hint"):
+            hint = exception.hint
+        set_session_hint(request, success=False, hint=hint)
+        return redirect("wiretransfer-form")
+
+    set_session_hint(request, success=True, hint=gettext("Wire transfer successful!"))
+    return redirect("profile")
+
 @login_required
 def payto_form(request):
+    is_success, hint = get_session_hint(request)
     context = dict(
         currency=request.user.bankaccount.balance.amount.currency,
+        is_success=is_success,
+        hint=hint,
     )
     return render(request, "payto_wiretransfer.html", context)
 
@@ -363,11 +394,18 @@ def payto_transfer(request):
         return redirect("profile")
 
     parsed_address = PaytoParse(data.cleaned_data.get("address"))
+
+    try:
+        receiver_user = User.objects.get(username=parsed_address.target)
+    except User.DoesNotExist:
+        set_session_hint(request, success=False, hint="Money receiver was not found")
+        return redirect("payto-form")
+
     wire_transfer(
         parsed_address.amount,
         BankAccount.objects.get(user=request.user),
-        BankAccount.objects.get(account_no=parsed_address.account),
-        parsed_address.subject,
+        BankAccount.objects.get(user=receiver_user),
+        parsed_address.message,
     )
     set_session_hint(request, success=True, hint=gettext("Wire transfer successful!"))
     return redirect("profile")
@@ -516,7 +554,7 @@ def register(request):
             "register.html",
             {
                 "wrong": True,
-                "hint": "Wrong field(s): %s." % ", ".join(form.errors.keys()),
+                "hint": gettext("Username or password were incorrect!"),
             },
         )
 
@@ -867,21 +905,43 @@ def twg_add_incoming(request, user_account, acct_id):
     debit_account = BankAccount.objects.get(user=debit_user)
     subject = f"{reserve_pub}"
 
-    wtrans = wire_transfer(
-        amount,
-        debit_account,
-        exchange_account,
-        subject,
-    )
+    # check if currency is acceptable
+    if amount.currency != settings.TALER_CURRENCY:
+        return JsonResponse(
+            {
+                "code": 30, # TALER_EC_BANK_DUPLICATE_RESERVE_PUB_SUBJECT
+                "hint": "The specified currency is not supported."
+            },
+            status=HTTPStatus.CONFLICT
+        )
 
+    # check if reserve pub exists already.
+    try:
+        BankTransaction.objects.get(subject=subject)
+
+    except BankTransaction.DoesNotExist:
+
+        wtrans = wire_transfer(
+            amount,
+            debit_account,
+            exchange_account,
+            subject)
+
+        return JsonResponse(
+            {
+                "row_id": wtrans.id,
+                "timestamp": dict(t_ms=(int(wtrans.date.timestamp()) * 1000)),
+            }
+        )
+    # Here means this public key was used already: must fail.
     return JsonResponse(
         {
-            "row_id": wtrans.id,
-            "timestamp": dict(t_ms=(int(wtrans.date.timestamp()) * 1000)),
-        }
+            "code": 5114, # TALER_EC_BANK_DUPLICATE_RESERVE_PUB_SUBJECT
+            "hint": "The reserve public cannot be used multiple times."
+        },
+        status=HTTPStatus.CONFLICT
     )
 
-
 @csrf_exempt
 @require_POST
 @login_via_headers
